# ApplePaySessionRequest

Initiates a new session with Apple Pay.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**validation_url** | **str** | Validation URL obtained from the event passed to a &#x60;onvalidatemerchant&#x60; callback. | 
**domain_name** | **str** | Fully qualified domain name of the merchant. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


